import { Base, Exponent, Integer, Logarithm, NoUse, Power, UnwholeVersion, Whole, WholeVersion } from '../nominal';
import { DifferenceOperation, ProductOperation, QuotientOperation, SumOperation } from './types';
declare const sum: SumOperation;
declare const difference: DifferenceOperation;
declare const product: ProductOperation;
declare const quotient: QuotientOperation;
declare const modulus: <NumericType extends NoUse | number>(dividend: NumericType, divisor: NumericType) => UnwholeVersion<NumericType>;
declare const reciprocal: <NumericType extends Number>(numeral: NumericType) => UnwholeVersion<NumericType>;
declare const negative: <NumericType extends Number>(numeral: NumericType) => NumericType;
declare const round: <NumericType extends Number, WholeType extends Whole = Integer>(numeral: NumericType, precision?: WholeType) => NumericType;
declare const floor: <NumericType extends Number>(numeral: NumericType) => WholeVersion<NumericType>;
declare const ceiling: <NumericType extends Number>(numeral: NumericType) => WholeVersion<NumericType>;
declare const absoluteValue: <NumericType extends Number>(numeral: NumericType) => NumericType;
declare const squareRoot: <NumericType extends Number>(numeral: NumericType) => UnwholeVersion<NumericType>;
declare const cubeRoot: <NumericType extends Number>(numeral: NumericType) => UnwholeVersion<NumericType>;
declare const max: <NumericType extends Number>(...numerals: NumericType[]) => NumericType;
declare const min: <NumericType extends Number>(...numerals: NumericType[]) => NumericType;
declare const pow: {
    <NumericType extends Number = number>(base: Base<NumericType>, power: Power<NumericType>): NumericType;
    <NumericType extends Number = number>(base: Logarithm<NumericType>, power: Exponent<NumericType>): NumericType;
};
declare const log: {
    <NumericType extends Number = number>(numeral: NumericType, base: Base<NumericType>): Power<NumericType>;
    <NumericType extends Number = number>(numeral: NumericType, base: Logarithm<NumericType>): Exponent<NumericType>;
};
export { sum, difference, product, quotient, modulus, reciprocal, negative, round, floor, ceiling, absoluteValue, squareRoot, cubeRoot, max, min, pow, log, };
